plugins

package
v0.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 18, 2026 License: MIT Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type PluginManager

type PluginManager struct {
	// contains filtered or unexported fields
}

PluginManager manages loading and accessing plugins

func NewPluginManager

func NewPluginManager() *PluginManager

NewPluginManager creates a new plugin manager

func (*PluginManager) GetPlugin

func (pm *PluginManager) GetPlugin(name string) (modules.Module, bool)

GetPlugin retrieves a plugin by name

func (*PluginManager) ListPlugins

func (pm *PluginManager) ListPlugins() []string

ListPlugins returns a list of all loaded plugin names

func (*PluginManager) LoadPlugin

func (pm *PluginManager) LoadPlugin(path string) error

LoadPlugin loads a single plugin from the specified path

func (*PluginManager) LoadPlugins

func (pm *PluginManager) LoadPlugins(pluginDir string) error

LoadPlugins loads all .so files from the specified directory

type PluginModule

type PluginModule struct {
	// contains filtered or unexported fields
}

PluginModule wraps a plugin's render function to implement the Module interface

func (*PluginModule) Name

func (p *PluginModule) Name() string

func (*PluginModule) Render

func (p *PluginModule) Render(info *collectors.SystemInfo, styles theme.Styles) string

Jump to